import { App } from 'vue';
import { DeepReadonly } from 'vue';
import { default as default_2 } from 'keycloak-js';
import { KeycloakConfig } from 'keycloak-js';
import { KeycloakError } from 'keycloak-js';
import { KeycloakInitOptions } from 'keycloak-js';
import { KeycloakLoginOptions } from 'keycloak-js';
import { KeycloakLogoutOptions } from 'keycloak-js';
import { KeycloakProfile } from 'keycloak-js';
import { KeycloakResourceAccess } from 'keycloak-js';
import { KeycloakRoles } from 'keycloak-js';
import { KeycloakTokenParsed } from 'keycloak-js';

declare const _default: {
    install: (app: App, params?: VueKeycloakOptions) => void;
};
export default _default;

export declare function useKeycloak(): DeepReadonly<VueKeycloakInstance>;

export declare type VueKeycloakConfig = KeycloakConfig | string;

export declare interface VueKeycloakInstance {
    ready: boolean;
    authenticated: boolean;
    userName?: string;
    fullName?: string;
    login?(options?: KeycloakLoginOptions): Promise<void>;
    loginFn?(options?: KeycloakLoginOptions): Promise<void>;
    logoutFn?(options?: default_2['logout']): Promise<void> | void;
    createLoginUrl?(options?: KeycloakLoginOptions): Promise<string>;
    createLogoutUrl?(options?: KeycloakLogoutOptions): string;
    createRegisterUrl?(options?: KeycloakLoginOptions): Promise<string>;
    register?(options?: KeycloakLoginOptions): Promise<void>;
    accountManagement?(): Promise<void>;
    createAccountUrl?(): string;
    loadUserProfile?(): Promise<KeycloakProfile>;
    subject?: string;
    idToken?: string;
    idTokenParsed?: VueKeycloakTokenParsed;
    realmAccess?: KeycloakRoles;
    resourceAccess?: KeycloakResourceAccess;
    refreshToken?: string;
    refreshTokenParsed?: VueKeycloakTokenParsed;
    timeSkew?: number;
    responseMode?: string;
    responseType?: string;
    hasRealmRole?(role: string): boolean;
    hasResourceRole?(role: string, resource?: string): boolean;
    token?: string;
    tokenParsed?: VueKeycloakTokenParsed;
    keycloak?: default_2;
}

export declare interface VueKeycloakOptions {
    config?: VueKeycloakConfig;
    init?: KeycloakInitOptions;
    logout?: KeycloakLogoutOptions;
    updateInterval?: number;
    autoRefreshToken?: boolean;
    onReady?: (keycloak: default_2, VueKeycloak?: VueKeycloakInstance) => void;
    onInitError?: (error: Error, err: KeycloakError) => void;
    onAuthLogout?: (keycloak: default_2) => void;
    onAuthRefreshError?: (keycloak: default_2) => void;
    onAuthRefreshSuccess?: (keycloak: default_2) => void;
    onInitSuccess?(authenticated: boolean): void;
}

export declare interface VueKeycloakTokenParsed extends KeycloakTokenParsed {
    preferred_username?: string;
    name?: string;
}

export { }
